pub struct Banned {
pub until_date: UntilDate,
}Expand description
User that was banned in the chat and can’t return to it or view chat
messages. This struct is part of the ChatMemberKind enum.
Fields
until_date: UntilDateDate when restrictions will be lifted for this user.