LoginUrl

Struct LoginUrl 

pub struct LoginUrl {
    pub url: Url,
    pub forward_text: Option<String>,
    pub bot_username: Option<String>,
    pub request_write_access: Option<bool>,
}
This object represents a parameter of the inline keyboard button used to automatically authorize a user.

Serves as a great replacement for the Telegram Login Widget when the user is coming from Telegram. All the user needs to do is tap/click a button and confirm that they want to log in:

Fields

url: Url

An HTTPS URL to be opened with user authorization data added to the query string when the button is pressed. If the user refuses to provide authorization data, the original URL without information about the user will be opened. The data added is the same as described in Receiving authorization data.

NOTE: You must always check the hash of the received data to verify the authentication and the integrity of the data as described in Checking authorization.

forward_text: Option<String>

New text of the button in forwarded messages.

bot_username: Option<String>

Username of a bot, which will be used for user authorization. See Setting up a bot for more details. If not specified, the current bot’s username will be assumed. The url’s domain must be the same as the domain linked with the bot. See Linking your domain to the bot for more details.

request_write_access: Option<bool>

Pass true to request the permission for your bot to send messages to the user.

Implementations

Source

impl LoginUrl

pub fn url(self, val: Url) -> Self

pub fn forward_text<S>(self, val: S) -> Self
where S: Into<String>,

pub fn bot_username<S>(self, val: S) -> Self
where S: Into<String>,

pub fn request_write_access(self, val: bool) -> Self