pub struct PassportElementErrorReverseSide {
pub type: PassportElementErrorReverseSideType,
pub file_hash: String,
}Expand description
Represents an issue with the reverse side of a document.
The error is considered resolved when the file with reverse side of the document changes.
Fields
type: PassportElementErrorReverseSideTypeThe section of the user’s Telegram Passport which has the issue.
file_hash: StringImplementations