pub struct PublicChatSupergroup {
pub username: Option<String>,
pub active_usernames: Option<Vec<String>>,
pub is_forum: bool,
pub sticker_set_name: Option<String>,
pub can_set_sticker_set: Option<bool>,
pub permissions: Option<ChatPermissions>,
pub slow_mode_delay: Option<u32>,
pub linked_chat_id: Option<i64>,
pub location: Option<ChatLocation>,
pub join_to_send_messages: Option<True>,
pub join_by_request: Option<True>,
}Fields
username: Option<String>A username, for private chats, supergroups and channels if available.
active_usernames: Option<Vec<String>>If non-empty, the list of all active chat usernames; for private chats,
supergroups and channels. Returned only from GetChat.
is_forum: booltrue, if the supergroup chat is a forum (has topics enabled).
sticker_set_name: Option<String>For supergroups, name of group sticker set. Returned only from
GetChat.
can_set_sticker_set: Option<bool>true, if the bot can change the group sticker set. Returned only
from GetChat.
permissions: Option<ChatPermissions>A default chat member permissions, for groups and supergroups.
Returned only from GetChat.
slow_mode_delay: Option<u32>The minimum allowed delay between consecutive messages sent by each
unpriviledged user. Returned only from GetChat.
linked_chat_id: Option<i64>Unique identifier for the linked chat, i.e. the discussion group
identifier for a channel and vice versa. Returned only in GetChat.
location: Option<ChatLocation>The location to which the supergroup is connected. Returned only in
GetChat.
join_to_send_messages: Option<True>True, if users need to join the supergroup before they can send
messages. Returned only in GetChat.
join_by_request: Option<True>True, if all users directly joining the supergroup need to be approved
by supergroup administrators. Returned only in GetChat.